@@ -17,7 +17,7 @@ def get_utc_now():
     now = datetime.utcnow()
     now = now.replace(microsecond=0)
     now = pytz.UTC.localize(now)
-    if hasattr(pytz.UTC, 'normalize'):
+    if hasattr(pytz.UTC, "normalize"):
         now = pytz.UTC.normalize(now)
     return now
 
@@ -38,6 +38,7 @@ class NowExpression(Expression):
     optional part `now` within a token. Only returns back
     whatever it gets, acting as an identity expression.
     """
+
     def get_value(self, value):
         return value
 
@@ -84,94 +85,98 @@ class ModifierExpression(Expression):
         )
 
 
+def start_current_quarter(dt):
+    q = (dt.month - 1) // 3
+    return start_quarter(dt, q)
+
+
+def start_quarter(dt, q):
+    return dt.replace(month=q * 3 + 1, day=1, hour=0, minute=0, second=0)
+
+
+def create_start_quarter(q):
+    return lambda dt: start_quarter(dt, q)
+
+
+def end_current_quarter(dt):
+    q = (dt.month - 1) // 3
+    return end_quarter(dt, q)
+
+
+def end_quarter(dt, q):
+    d = 30 if q in (1, 2) else 31
+    return dt.replace(month=q * 3 + 3, day=d, hour=23, minute=59, second=59)
+
+
+def create_end_quarter(q):
+    return lambda dt: end_quarter(dt, q)
+
+
 class SnapExpression(Expression):
     __operations__ = {
         TokenType.SLASH: {
             "s": lambda dt: dt.replace(second=0),
             "m": lambda dt: dt.replace(second=0),
             "h": lambda dt: dt.replace(minute=0, second=0),
-            "d": lambda dt: dt.replace(
+            "d": lambda dt: dt.replace(hour=0, minute=0, second=0),
+            "w": lambda dt: (dt - td(days=dt.weekday())).replace(
                 hour=0, minute=0, second=0
             ),
-            "w": lambda dt: (
-                dt - td(days=dt.weekday())
-            ).replace(hour=0, minute=0, second=0),
-            "M": lambda dt: dt.replace(
-                day=1, hour=0, minute=0, second=0
-            ),
-            "Y": lambda dt: dt.replace(
-                month=1, day=1, hour=0, minute=0, second=0
-            ),
-            "bw": lambda dt: (
-                dt - td(days=dt.weekday())
-            ).replace(hour=0, minute=0, second=0),
-            "mon": lambda dt: (
-                dt - td(days=dt.weekday())
-            ),
-            "tue": lambda dt: (
-                dt - td(days=((dt.weekday() - 1) % 7))
-            ),
-            "wed": lambda dt: (
-                dt - td(days=((dt.weekday() - 2) % 7))
-            ),
-            "thu": lambda dt: (
-                dt - td(days=((dt.weekday() - 3) % 7))
-            ),
-            "fri": lambda dt: (
-                dt - td(days=((dt.weekday() - 4) % 7))
-            ),
-            "sat": lambda dt: (
-                dt - td(days=((dt.weekday() - 5) % 7))
-            ),
-            "sun": lambda dt: (
-                dt - td(days=((dt.weekday() - 6) % 7))
+            "M": lambda dt: dt.replace(day=1, hour=0, minute=0, second=0),
+            "Y": lambda dt: dt.replace(month=1, day=1, hour=0, minute=0, second=0),
+            "bw": lambda dt: (dt - td(days=dt.weekday())).replace(
+                hour=0, minute=0, second=0
             ),
+            "mon": lambda dt: (dt - td(days=dt.weekday())),
+            "tue": lambda dt: (dt - td(days=((dt.weekday() - 1) % 7))),
+            "wed": lambda dt: (dt - td(days=((dt.weekday() - 2) % 7))),
+            "thu": lambda dt: (dt - td(days=((dt.weekday() - 3) % 7))),
+            "fri": lambda dt: (dt - td(days=((dt.weekday() - 4) % 7))),
+            "sat": lambda dt: (dt - td(days=((dt.weekday() - 5) % 7))),
+            "sun": lambda dt: (dt - td(days=((dt.weekday() - 6) % 7))),
+            "Q": start_current_quarter,
+            "Q1": create_start_quarter(0),
+            "Q2": create_start_quarter(1),
+            "Q3": create_start_quarter(2),
+            "Q4": create_start_quarter(3),
         },
         TokenType.AT: {
-            "s": lambda dt: dt.replace(
-                second=0, millisecond=999
-            ),
+            "s": lambda dt: dt.replace(second=0, millisecond=999),
             "m": lambda dt: dt.replace(second=59),
-            "h": lambda dt: dt.replace(
-                minute=59, second=59
-            ),
-            "d": lambda dt: dt.replace(
+            "h": lambda dt: dt.replace(minute=59, second=59),
+            "d": lambda dt: dt.replace(hour=23, minute=59, second=59),
+            "w": lambda dt: (dt - td(days=dt.weekday()) + td(days=6)).replace(
                 hour=23, minute=59, second=59
             ),
-            "w": lambda dt: (
-                dt - td(days=dt.weekday()) + td(days=6)
-            ).replace(hour=23, minute=59, second=59),
-            "M": lambda dt: (
-                dt + relativedelta(months=1, days=-dt.day)
-            ).replace(hour=23, minute=59, second=59),
-            "Y": lambda dt: dt.replace(
-                year=dt.year + 1, month=1, day=1,
-                hour=0, minute=0, second=0,
-            ) - relativedelta(seconds=1),
-            "bw": lambda dt: (
-                dt - td(days=dt.weekday()) + td(days=4)
-            ).replace(hour=23, minute=59, second=59),
-            "mon": lambda dt: (
-                dt + td(days=((0 - dt.weekday()) % 7))
+            "M": lambda dt: (dt + relativedelta(months=1, days=-dt.day)).replace(
+                hour=23, minute=59, second=59
             ),
-            "tue": lambda dt: (
-                dt + td(days=((1 - dt.weekday()) % 7))
+            "Y": (
+                lambda dt: dt.replace(
+                    year=dt.year + 1,
+                    month=1,
+                    day=1,
+                    hour=0,
+                    minute=0,
+                    second=0,
+                )
+                - relativedelta(seconds=1)
             ),
-            "wed": lambda dt: (
-                dt + td(days=((2 - dt.weekday()) % 7))
-            ),
-            "thu": lambda dt: (
-                dt + td(days=((3 - dt.weekday()) % 7))
-            ),
-            "fri": lambda dt: (
-                dt + td(days=((4 - dt.weekday()) % 7))
-            ),
-            "sat": lambda dt: (
-                dt + td(days=((5 - dt.weekday()) % 7))
-            ),
-            "sun": lambda dt: (
-                dt + td(days=((6 - dt.weekday()) % 7))
+            "bw": lambda dt: (dt - td(days=dt.weekday()) + td(days=4)).replace(
+                hour=23, minute=59, second=59
             ),
+            "mon": lambda dt: (dt + td(days=((0 - dt.weekday()) % 7))),
+            "tue": lambda dt: (dt + td(days=((1 - dt.weekday()) % 7))),
+            "wed": lambda dt: (dt + td(days=((2 - dt.weekday()) % 7))),
+            "thu": lambda dt: (dt + td(days=((3 - dt.weekday()) % 7))),
+            "fri": lambda dt: (dt + td(days=((4 - dt.weekday()) % 7))),
+            "sat": lambda dt: (dt + td(days=((5 - dt.weekday()) % 7))),
+            "sun": lambda dt: (dt + td(days=((6 - dt.weekday()) % 7))),
+            "Q": end_current_quarter,
+            "Q1": create_end_quarter(0),
+            "Q2": create_end_quarter(1),
+            "Q3": create_end_quarter(2),
+            "Q4": create_end_quarter(3),
         },
     }
 
@@ -180,9 +185,7 @@ class SnapExpression(Expression):
         self.modifier = modifier
 
     def get_value(self, value):
-        fn = self.__operations__[self.operator][
-            self.modifier
-        ]
+        fn = self.__operations__[self.operator][self.modifier]
         return fn(value)
 
     def __str__(self):
